# Channel Access Filtering Example
This example exercises the [Epics Channel Filters](http://www.aps.anl.gov/epics/base/R3-15/5-docs/filters.html) functionality with PyDM.

# Prerequisites
* pydm
* Epics Base R3.15.5 or greater

# Running the Examples
In one shell do:
```sh
testIoc -d test.db &
pydm ca_filtering.ui
```

